summaryrefslogtreecommitdiff
path: root/ace
diff options
context:
space:
mode:
authorSteve Huston <shuston@riverace.com>2002-07-29 21:34:57 +0000
committerSteve Huston <shuston@riverace.com>2002-07-29 21:34:57 +0000
commit52d47667101d78d28d41778c8977d989f685401e (patch)
tree9fa2adc7edd0534753bbc352078ab239f49aec35 /ace
parent88cef5f301868c6b8dbd3b161c66312d990e641f (diff)
downloadATCD-52d47667101d78d28d41778c8977d989f685401e.tar.gz
ChangeLogTag:Mon Jul 29 17:30:27 2002 Steve Huston <shuston@riverace.com>
Diffstat (limited to 'ace')
-rw-r--r--ace/Get_Opt.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/ace/Get_Opt.h b/ace/Get_Opt.h
index 4a4f47fcb6a..d893ca29b77 100644
--- a/ace/Get_Opt.h
+++ b/ace/Get_Opt.h
@@ -106,12 +106,12 @@ public:
* long option, that is, as if "program --foo" had
* been passed.
*
* @param skip_argv0 Optional (default 1). The specified number of
* initial elements in @a argv are skipped before
* parsing begins. Thus, the default prevents
* @a argv[0] (usually the command name) from being
- * parsed. This value of @a argc includes all skipped
- * elements of @a argv specified by this parameter.
+ * parsed. @a argc includes all @a argv elements,
+ * including any skipped elements.
* @param report_errors Optional, if non-zero then parsing errors cause
* an error message to be displayed from the
* @c operator() method before it returns. The
@@ -154,7 +154,7 @@ public:
ACE_Get_Opt (int argc,
ACE_TCHAR **argv,
const ACE_TCHAR *optstring,
- int skip_argv0 = 1,
+ int skip_args = 1,
int report_errors = 0,
int ordering = PERMUTE_ARGS,
int long_only = 0);
@@ -106,12 +106,12 @@ public:
* been passed.
*
- * @param skip_argv0 Optional (default 1). The specified number of
+ * @param skip_args Optional (default 1). The specified number of
* initial elements in @a argv are skipped before
* parsing begins. Thus, the default prevents